@@ -4,10 +4,11 @@ from PySide import QtCore, QtGui
 import base64
 
 
-# Usage: Toast('Message')
 class PopupBubble(QtGui.QDialog):
     def __init__(self, title, msg, duration=2):
-        QtGui.QDialog.__init__(self)
+        # QtGui.QDialog.__init__(self)
+        super().__init__()
+        # super(PopupBubble, self).__init__(self)
         self.duration = duration
         self.title_label = QtGui.QLabel(self.make_bold(title))
         self.title_label.setWordWrap(True)
